@@ -3,7 +3,7 @@ from ..general import ClassDomain, Label
 from ..general import Field, Struct
 from ..general import DataSample
 from tqdm import tqdm
-from ..io import PetrelBackend, AliyunOSSBackend, HardDiskBackend, FileIO
+from ..io import HardDiskBackend, FileIO
 
 
 class DetectionParse:
@@ -11,16 +11,10 @@ class DetectionParse:
     DETECTION_ANN_TYPE = "box2d"
     PARENT_PATTERN = "Parent"
 
-    def __init__(self, data_info_file, ann_file, separate_flag, dataset_name=None, config=None):
-        if FileIO.is_ceph_path(data_info_file):
-            self.file_client = PetrelBackend()
-        elif FileIO.is_oss_path(data_info_file):
-            assert config, "you must provide the configuration of aliyun oss."
-            bucket_name = FileIO.get_bucket_name(data_info_file)
-            data_info_file = FileIO.get_oss_rel_path(data_info_file)
-            ann_file = FileIO.get_oss_rel_path(ann_file)
-            self.file_client = AliyunOSSBackend(bucket_name=bucket_name, **config)
-        else:  # read from local
+    def __init__(self, data_info_file, ann_file, separate_flag, dataset_name=None, file_client=None):
+        if file_client:
+            self.file_client = file_client
+        else:
             self.file_client = HardDiskBackend()
         self.separate_flag = separate_flag
         self._dataset_name = dataset_name
